@@ -8,7 +8,7 @@ class SlackNotifier:
         self.token = token
         self.alert_channel = alert_channel
 
-    def alert(self, msg):
+    def message(self, msg):
         client = WebClient(token=self.token)
         try:
             response = client.chat_postMessage(
